@@ -16,13 +16,14 @@ def docs(api, apiVersion='0.0', swaggerVersion='1.2',
          basePath='http://localhost:5000',
          resourcePath='/',
          produces=["application/json"],
-         api_spec_url='/api/spec'):
+         api_spec_url='/api/spec',
+         description='Auto generated API docs by flask-restful-swagger'):
 
   api_add_resource = api.add_resource
 
   def add_resource(resource, path, *args, **kvargs):
     register_once(api, api_add_resource, apiVersion, swaggerVersion, basePath,
-                  resourcePath, produces, api_spec_url)
+                  resourcePath, produces, api_spec_url, description)
 
     resource = make_class(resource)
     endpoint = swagger_endpoint(api, resource, path)
@@ -54,7 +55,7 @@ def make_class(class_or_instance):
 
 
 def register_once(api, add_resource_func, apiVersion, swaggerVersion, basePath,
-                  resourcePath, produces, endpoint_path):
+                  resourcePath, produces, endpoint_path, description):
   global api_spec_static
   global resource_listing_endpoint
 
@@ -68,7 +69,8 @@ def register_once(api, add_resource_func, apiVersion, swaggerVersion, basePath,
       'resourcePath': resourcePath,
       'produces': produces,
       'x-api-prefix': '',
-      'apis': []
+      'apis': [],
+      'description': description
     }
 
     def registering_blueprint(setup_state):
@@ -101,6 +103,7 @@ def register_once(api, add_resource_func, apiVersion, swaggerVersion, basePath,
       'spec_endpoint_path': endpoint_path,
       'resourcePath': resourcePath,
       'produces': produces,
+      'description': description
     }
 
     add_resource_func(
@@ -228,7 +231,7 @@ class ResourceLister(Resource):
         {
           "path": (
             req_registry['basePath'] + req_registry['spec_endpoint_path']),
-          "description": "Auto generated API docs by flask-restful-swagger"
+          "description": req_registry['description']
         }
       ]
     }
@@ -305,7 +308,7 @@ class SwaggerEndpoint(object):
               op[att_name] = att_value
           elif isinstance(att_value, object):
             op[att_name] = att_value.__name__
-      operations.append(op)
+        operations.append(op)
     return operations
 
 
@@ -419,6 +422,10 @@ def add_model(model_class):
     for k, v in defaults:
       properties[k] = {'type': 'string', "default": v}
 
+  if 'swagger_metadata' in dir(model_class):
+    for field_name, field_metadata in model_class.swagger_metadata.items():
+        if field_name in properties:
+            properties[field_name] = dict(properties[field_name].items() + field_metadata.items())
 
 def deduce_swagger_type(python_type_or_object, nested_type=None):
     import inspect
